#!/bin/bash
# author           : P.R. Faasse (faasse@nlr.nl) <prf>
# maintainer       : P.R. Faasse
# source location  : see $srcurl1/srcurl2 below
# additional files : the mozilla plugin for kaffeine
#
# remarks          :
# - xine-lib is built 'i686'; so running/installing this on a <'i686'
#   machine will prbably not make much sense
#
# update history   :
#
# 27-jan-2008: update to version 0.8.6, and included the mozilla plugin
#              added the generation of the .src file
#              <prf>
#
#  1-feb-2008: The mozilla plugin was not in the right place for
#              mozilla/iceweasel to find it: should be in 
#              /usr/lib/mozilla/plugins, not in /usr/plugins....
# 
# 10-aug-2008: version upgrade to 0.8.7. Experimental build-option
#              added "-fasynchronous-unwind-tables" as reported in the
#              zenwalk forum 
#     see: http://support.zenwalk.org/viewtopic.php?f=36&t=12791&sid=2a9f403b893f039ea43bea92b26266ef
#

#
# what package is going to be built
#
softname='kaffeine'
softversion='0.8.8'
archive1="$softname-$softversion.tar.bz2"

softname2="kaffeine-mozilla"
softversion2="0.2"
archive2="$softname2-$softversion2.tar.bz2"

#
# The ZenWalk package version: indicated for/on what ZenWalk version
# the package has been created
#
# example: packageversion='1Z20' means: 
# 1  -> build 1 = first build, special: 0 = experimental/unsupported build
# Z  -> ZenWalk
# 20 -> ZenWalk version 2.0; 26 -> zenwalk 2.6 
#
packageversion='64.1'

#
# where could you get the source
#
srcurl1="http://hftom.free.fr/kaffeine-0.8.8.tar.bz2"
srcurl2="http://garr.dl.sourceforge.net/sourceforge/kaffeine/kaffeine-mozilla-0.2.tar.bz2"

#
# building-computer dependent: the number of parallel 'jobs' of 'make'
#
# 'heavy' computer: 6 make-jobs at once
#
#numjobs='-j6'
#
# I only have a 'light' computer: 2 make-jobs at once
#
numjobs='-j2'

#
#---------------------------------------------------------------------
# Note: for a rebuild you should normally not have to change anything
# below this comment
#---------------------------------------------------------------------
#

#
# a lonesome 'hook': the other end is at the bottom of the buildfile
# the combination gives me a full log of the build-process in the
# file: "$softname-$softversion-info.txt"
#
(

#
# we're going to do some cwd-hopping: this requires that we keep track
# of the starting-point
#
buildir=$(pwd)

#
# We'll use the SlackWare/ZenWalk database of installed packages: 
# The directory: /var/log/packages keeps a set of all installed 
# ZenWalk packages: one file per installed package
#


echo "-- dependencies check -----"

depsok=passed

cd /var/log/packages
 
#
# 
#
for file in \
	kdelibs \
	qt-base \
	xine-lib \
; do
 
   #
   # Check the dependency
   #
   if [ -f $file* ] ; then 
      echo "package: $file is installed: `ls -d $file*`: good ...";
   else
      echo "package: $file not found: please install a $file package first";
      depsok=fail
   fi

done

cd $buildir
 
echo "Dependencies check result: $depsok"
#
# check if all dependencies are there
#
if [[ $depsok == passed ]]; then
   unset $depsok;
else
   exit 1;
fi

#
# check if the source files archive is present: we can do little without
# it
#
echo "-- source archive check -----"

if [ -r "$archive1" ]; then 
  echo "Usable source archive: $archive1 found: good ...";
else 
  echo "No source archive: $archive1 found"
  echo "It is not possible to build the package without a source archive"
  echo "file; Please download the source archive from:"
  echo
  echo "$srcurl1"
  echo
  exit 1;
fi

if [ -r "$archive2" ]; then 
  echo "Usable source archive: $archive2 found: good ...";
else 
  echo "No source archive: $archive2 found"
  echo "It is not possible to build the package without a source archive"
  echo "file; Please download the source archive from:"
  echo
  echo "$srcurl2"
  echo
  exit 1;
fi


#
# start the real work
#
echo "-- start of the package building -----"

#
# the package 'destination'
#
prefix=/usr

#
# The architecture that the package is built for:
#
# arch='i486' -> the compiler uses only 80486 instructions
# tune='i686'  -> the optimising is done for a PII and above CPU
#
arch='i686'
tune='i686'

#
# parameters needed for the build process
#
package="$softname-$softversion-$arch-$packageversion"

#
# do package-specific settings 
#

#
# prepare the build result directory
#
dest="$buildir/$package"
#
rm -rf $dest
#
mkdir -p $dest
mkdir -p $dest/install
mkdir -p $dest/$prefix/bin
#
# prepare the directory for the build-file and assorted other 
# user-build related things
#
destsrc="$dest/usr/src/$softname-$softversion"
mkdir -p $destsrc

#
# put a slack-desc in place
#
BBSStrng=`echo $softname | sed "s/./ /g"`

cat <<EOF > $dest/install/slack-desc
$BBSStrng|-----handy-ruler------------------------------------------------------|
$softname: Media player for KDE
$softname: 
$softname: Yet another media player for kde. 
$softname:
$softname: This build includes the kaffeine-mozilla plugin
$softname: 
$softname: 
$softname: 
$softname: 
$softname:
$softname: 
EOF

echo "-- building the kaffeine media player -----"
echo "-- Unpacking the source archive -----"

#
cd $buildir
file=$archive1
srcdir="$(basename $file .tar.bz2)" 
rm -rf $srcdir
tar xf $file
cd $srcdir  

#
# set target permissions
#
chown -R root.root . 
find . -perm 777 -exec chmod 755 {} \;
find . -perm 775 -exec chmod 755 {} \;
find . -perm 666 -exec chmod 644 {} \;
find . -perm 664 -exec chmod 644 {} \;

#
# configure package for compilation
#
echo "-- configure -----"

export PATH=/usr/lib/kde/bin:$PATH
export KDEDIR=/usr/lib/kde

export CFLAGS="-O2 -march=$arch -mtune=$tune -I/usr/lib/kde/include -I/usr/include/cdda"
export CXXFLAGS="-O2 -march=$arch -mtune=$tune -I/usr/lib/kde/include -I/usr/include/cdda"

./configure \
  --prefix=/usr \
  --mandir=/usr/man \
  --localstatedir=/var \
  --sysconfdir=/etc \
  --program-prefix="" \
  --program-suffix="" 

#
# make package
#
echo "-- make -----"
make $numjobs 

#
# install package to the target directory
#
echo "-- make install -----"
make install DESTDIR=$dest

#
# add 'default' files from the package source
#
echo "-- adding default files -----"

mkdir -p $dest/usr/doc/$srcdir
cp -a \
  AUTHORS COPYING INSTALL NEWS README TODO ChangeLog \
  $dest/usr/doc/$srcdir 

echo "-- building the kaffeine media player mozilla plugin -----"
echo "-- Unpacking the source archive -----"

#
cd $buildir
file=$archive2
srcdir="$(basename $file .tar.bz2)" 
rm -rf $srcdir
tar xf $file
cd $srcdir  

#
# set target permissions
#
chown -R root.root . 
find . -perm 777 -exec chmod 755 {} \;
find . -perm 775 -exec chmod 755 {} \;
find . -perm 666 -exec chmod 644 {} \;
find . -perm 664 -exec chmod 644 {} \;

#
# configure package for compilation
#
echo "-- configure -----"

export CFLAGS="-O2 -march=$arch -mtune=$tune"  
export CXXFLAGS="-O2 -march=$arch -mtune=$tune"  
./configure \
  --prefix=/usr/lib/mozilla \
  --mandir=/usr/man \
  --localstatedir=/var \
  --sysconfdir=/etc \
  --program-prefix="" \
  --program-suffix="" 

#
# make package
#
echo "-- make -----"
make $numjobs 

#
# install package to the target directory
#
echo "-- make install -----"
make install DESTDIR=$dest

#
# add 'default' files from the package source
#
echo "-- adding default files -----"

mkdir -p $dest/usr/doc/$srcdir
cp -a \
  AUTHORS COPYING INSTALL NEWS README TODO ChangeLog \
  $dest/usr/doc/$srcdir 

# 
# as per package rules: add the build-file itself
#
echo "-- adding package-rules files -----"

cp "$buildir/build-$softname.sh" \
   "$destsrc/build-$softname.sh"
chmod a+x "$destsrc/build-$softname.sh"
#
# generate an executable script that can be used to get the source
#
cat <<EOF > "$destsrc/getsrc.sh"
# 
# get the source(s) script
#
wget -c $srcurl
EOF

#
# it works easier if this file is actually executable :-)
#
chmod a+x "$destsrc/getsrc.sh"

#
# post-build processing: 
# - strip executables 
# - compress man-pages
#
echo "-- pre-package processing files -----"

( cd $dest
  find . | xargs file | grep "executable" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
  find . | xargs file | grep "shared object" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
  for mandir in $(find . -name man -type d) ; do
    if [ -d $mandir ]; then
      ( cd $mandir
        find . -type f -name "*.?" -exec gzip -9 {} \;
      )
    fi
  done
)

#
# real packaging work: 
#
chown -R root.root $dest/$prefix

echo "--- packaging -----"

cd $dest
makepkg -p -l y -c n $dest.txz
(
 cd $buildir
 #
 md5sum $package.txz >$package.md5
 #
 requiredbuilder -z $package.txz >$package.dep
 #
 cat <<EOF >$package.src
$srcurl1
$srcurl2
EOF
)

#
# the other end of the lonesome hook: 
#
) 2>&1 | tee "$softname-$softversion-info.txt"

